/**
 * The MIT License (MIT)
 * 
 * Copyright (c) 2014-2015 Keld Oelykke
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package starkcoder.failfast.fails;

/**
 * Top-level concrete fail-fast exception.
 * <p>
 * All fail-fast exceptions created by this or a derived class can be caught, if
 * needed.
 * </p>
 * 
 * @author Keld Oelykke
 */
public class FailFastException extends AFailFastException
{

	/**
	 * Constructor called by {link: IFailer} when a check asserts and failer is
	 * called.
	 * 
	 * @param message
	 *            compound message specified by fail method.
	 */
	public FailFastException(String message)
	{
		super(message);
	}

	/**
	 * Constructor that can be used to nest an exception in a fail-fast
	 * exception.
	 * 
	 * @param message
	 *            custom message to specify.
	 * @param throwable
	 *            exception to nest
	 */
	public FailFastException(String message, Throwable throwable)
	{
		super(message, throwable);
	}

	/**
	 * Version specific id of this class for serialization purposes.
	 */
	private static final long serialVersionUID = 3308352080068039213L;

}
